#!/usr/bin/env python

import argparse
import os
import spectral.io
from perlin2d import *


def main():
    parser = argparse.ArgumentParser()
    parser.add_argument("--width",
                        help="Width of the map",
                        type=int,
                        default=256)
    parser.add_argument("--height",
                        help="Height of the map",
                        type=int,
                        default=256)
    parser.add_argument(
        "--percent_var",
        type=float,
        help=
        "Standard deviation for added noise (percent difference in each coefficient)",
        default=1)
    parser.add_argument("--iterative",
                        help="Whether the map should be iterative Balfour",
                        action="store_true")
    args = parser.parse_args()

    params = [-190.876, 4.30008e-02, 0.00367805, 0.676968, 0.00041509]
    params = [-400, 0.1, 0.01, 1, -0.0005]
    if args.iterative:
        params.append(0.5)

    bMap = np.zeros((args.height, args.width, len(params)), dtype=float)
    for i in range(0, len(params)):
        if i < 5:
            # Make a mean = 0, std dev = 1 percent difference map
            percentDiffMap = generate_fractal_noise_2d(
                (args.height, args.width), (8, 8), 5)
            percentDiffMap = (percentDiffMap -
                              np.mean(percentDiffMap)) / np.std(percentDiffMap)
            percentDiffMap = (args.percent_var / 100) * percentDiffMap

            bMap[:, :, i] = params[i] * (1 + percentDiffMap)
        else:
            bMap[:, :, i] = params[i]

    spectral.io.envi.save_image("background.img.hdr", bMap, force=True)
    os.rename("background.img.img", "background.img")


if __name__ == "__main__":
    main()
